#
# spec file for package luit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define tarballver 2.0.

Name:           luit
Version:        20230201
Release:        1.3
Summary:        Locale and ISO 2022 support for Unicode terminals
License:        MIT
Group:          System/X11/Utilities
URL:            http://invisible-island.net/luit/
Source0:        https://invisible-island.net/archives/%{name}/current/%{name}-%{tarballver}%{version}.tgz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(fontenc)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Luit is a filter that can be run between an arbitrary application and a
UTF-8 terminal emulator. It will convert application output from the
locale's encoding into UTF-8, and convert terminal input from UTF-8 into
the locale's encoding.

%prep
%setup -q -n %{name}-%{tarballver}%{version}

%build
%configure --with-localealiasfile=%{_datadir}/X11/locale/locale.alias
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%{_bindir}/luit
%{_mandir}/man1/luit.1%{?ext_man}

%changelog
* Mon Dec 11 2023 Jiri Srain <jsrain@suse.com>
- fixed upstream tarball URL
* Mon Feb  6 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 2.0.20230201
  * correct  conversion  to/from  codes  past  BMP  (patch by Ben Wong,
    Debian #1027414)
  * fix a few compiler-warnings in configure-checks
* Sat Oct 29 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 20221028
  * fix a few compiler-warnings
  * updated plink.sh, from xterm.
  * updated configure script, to work around regression in grep 3.8
  * updated configure macros for compiler-warning fixes.
  * update config.guess, config.sub, install-sh
* Tue Oct  6 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 20201003
  * updated configure macros:
    + compiler-warning fixes
    + build-fixes for OpenBSD and macOS
  * update config.guess, config.sub
* Mon May 23 2016 sndirsch@suse.com
- removed u_luit-Set-up-terminal-before-fork.diff; upstream author
  and maintainer Thomas Dickey can't reproduce the issue and
  downstream, i.e. me, doesn't know how to reproduce it either ...
* Wed Apr 20 2016 sndirsch@suse.com
- Update to version 20150706
  * add configure option --with-man2html
  * updated configure macros, mostly formatting changes from xterm, etc.
  * update config.guess, config.sub
* Sun Mar  1 2015 p.drouand@gmail.com
- Update to version 20141204
  * Maintainance update
- Use upstream versioning scheme
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Mar  4 2013 sndirsch@suse.com
- update to version 2.0-20130217
* Mon Oct 15 2012 sndirsch@suse.com
- switched to fontenc instead of iconv (includes support for CJK)
* Mon Oct 15 2012 sndirsch@suse.com
- Update to version 1.2-20121014:
  * review/improve no-leaks checking with valgrind.
  * add  null-pointer checks in copyOut in case a non-8bit encoding was
    used with the iconv configuration.
  * document environment variables used by luit in its manpage.
  * amend  the  check using nl_langinfo(CODESET) in 2011/10/30 changes,
    ignoring  that section if the -encoding option was given (report by
    Alexios Zavras). (bnc#781836)
  * support --datarootdir option in configure script.
  * updated configure macros:
  * update config.guess, config.sub
* Thu May 10 2012 vuntz@opensuse.org
- Update to version 1.2-20120129:
  + Add some error checking for the poll and select logic to avoid
    looping when a file descriptor is no longer valid.
  + Various portability fixes.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split luit from xorg-x11. Initial version: 1.2-20111030.
